@@ -1,13 +1,11 @@
-# A very simple setup script to test adding summary data stream to an MSI file.
-#
-# hello.py is a very simple 'Hello, world' type script which also displays the
-# environment in which the script runs
-#
-# Run the build process by running the command 'python setup.py bdist_msi'
+"""A very simple setup script to test adding summary data stream to an MSI
+file.
 
+hello.py is a very simple 'Hello, world' type script which also displays the
+environment in which the script runs
 
-from __future__ import annotations
-
+Run the build process by running the command 'python setup.py bdist_msi'
+"""
 from cx_Freeze import Executable, setup
 
 executables = [Executable("hello.py")]
